export CONDA_BUILD="1"
export PYTHONNOUSERSITE="1"
export CONDA_DEFAULT_ENV="/tmp/build/80754af9/pymongo_1620214127779/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh"
export ARCH="64"
export PREFIX="/tmp/build/80754af9/pymongo_1620214127779/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh"
export BUILD_PREFIX="/tmp/build/80754af9/pymongo_1620214127779/_build_env"
export SYS_PREFIX="/opt/conda"
export SYS_PYTHON="/opt/conda/bin/python"
export SUBDIR="linux-64"
export build_platform="linux-64"
export SRC_DIR="/tmp/build/80754af9/pymongo_1620214127779/work"
export ROOT="/opt/conda"
export CONDA_PY="36"
export PY3K="1"
export PY_VER="3.6"
export STDLIB_DIR="/tmp/build/80754af9/pymongo_1620214127779/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/lib/python3.6"
export SP_DIR="/tmp/build/80754af9/pymongo_1620214127779/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/lib/python3.6/site-packages"
export PYTHON="/tmp/build/80754af9/pymongo_1620214127779/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/bin/python"
export NPY_VER="1.16"
export CONDA_NPY="116"
export NPY_DISTUTILS_APPEND_FLAGS="1"
export PERL_VER="5.26"
export CONDA_PERL="5.26"
export LUA_VER="5"
export CONDA_LUA="5"
export R_VER="3.5"
export CONDA_R="3.5"
export PKG_NAME="pymongo"
export PKG_VERSION="3.11.4"
export PKG_BUILDNUM="0"
export PKG_BUILD_STRING="placeholder"
export PKG_HASH="1234567"
export RECIPE_DIR="/tmp/build/80754af9/combined_recipe"
export CPU_COUNT="12"
export LANG="en_US.UTF-8"
export LC_ALL="en_US.UTF-8"
export SHLIB_EXT=".so"
export PATH="/tmp/build/80754af9/pymongo_1620214127779/_build_env:/tmp/build/80754af9/pymongo_1620214127779/_build_env/bin:/tmp/build/80754af9/pymongo_1620214127779/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh:/tmp/build/80754af9/pymongo_1620214127779/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/bin:/opt/conda/bin:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin"
export HOME="/root"
export PKG_CONFIG_PATH="/tmp/build/80754af9/pymongo_1620214127779/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/lib/pkgconfig"
export CMAKE_GENERATOR="Unix Makefiles"
export LD_RUN_PATH="/tmp/build/80754af9/pymongo_1620214127779/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/lib"
export BUILD="x86_64-conda_cos6-linux-gnu"
export pin_run_as_build="OrderedDict([('python', {'max_pin': 'x.x', 'min_pin': 'x.x'}), ('r-base', {'max_pin': 'x.x', 'min_pin': 'x.x'}), ('libboost', {'max_pin': 'x.x.x'})])"
export extend_keys="{'ignore_build_only_deps', 'extend_keys', 'pin_run_as_build', 'ignore_version'}"
export ignore_build_only_deps="{'python', 'numpy'}"
export libgsasl="1.8"
export VERBOSE_CM="VERBOSE=1"
export pixman="0.30"
export noarch_python="python"
export qtwebkit="true"
export hdfeos5="5.1"
export gst_plugins_base="1.14"
export r_version="3.5.0"
export cairo="1.14"
export libtiff="4.1"
export glib="2"
export readline="8.0"
export mpfr="4"
export c_compiler_version="7.3.0"
export freetype="2.10"
export boost="1.73"
export channel_targets="defaults"
export libgd="2.2.5"
export macos_min_version="10.9"
export cran_mirror="https://mran.microsoft.com/snapshot/2018-01-01"
export hdfeos2="2.20"
export xz="5"
export openjpeg="2.3"
export c_compiler="gcc"
export fortran_compiler_version="7.3.0"
export libwebp="1.0.0"
export libxml2="2.9"
export libkml="1.3"
export lzo="2"
export hdf4="4.2"
export rust_compiler_version="1.46.0"
export geos="3.8.0"
export bzip2="1.0"
export libxslt="1.1"
export gnu="2.12.2"
export target_platform="linux-64"
export VERBOSE_AT="V=1"
export llvm_variant="llvm"
export apr="1.6.3"
export python_implementation="cpython"
export sqlite="3"
export proj4="5.2.0"
export cxx_compiler_version="7.3.0"
export jpeg="9"
export rust_compiler="rust"
export fontconfig="2.13"
export clang_variant="clang"
export dbus="1"
export cxx_compiler="gxx"
export libffi="3.3"
export zlib="1.2"
export macos_machine="x86_64-apple-darwin13.4.0"
export libpng="1.6"
export libprotobuf="3.11.2"
export proj="6.2.1"
export libdap4="3.19"
export hdf5="1.10.6"
export g2clib="1.6"
export cyrus_sasl="2.1.26"
export serf="1.3.9"
export cpu_optimization_target="nocona"
export blas_impl="mkl"
export mkl="2021"
export python_impl="cpython"
export openssl="1.1.1"
export openblas="0.3.3"
export MACOSX_DEPLOYMENT_TARGET="10.9"
export boost_cpp="1.73"
export gstreamer="1.14"
export icu="58"
export fortran_compiler="gfortran"
export giflib="5"
export gmp="6.1"
export r_base="3.5"
export r_implementation="mro-base"
export libgdal="3.0"
export harfbuzz="2.4"
export libnetcdf="4.6"
export tk="8.6"
export expat="2.2"
export CONDA_BUILD_STATE="BUILD"
export PIP_NO_BUILD_ISOLATION="False"
export PIP_NO_DEPENDENCIES="True"
export PIP_IGNORE_INSTALLED="True"
export PIP_CACHE_DIR="/tmp/build/80754af9/pymongo_1620214127779/pip_cache"
export PIP_NO_INDEX="True"
eval "$('/opt/conda/bin/python' -m conda shell.bash hook)"
conda activate "/tmp/build/80754af9/pymongo_1620214127779/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh"
conda activate --stack "/tmp/build/80754af9/pymongo_1620214127779/_build_env"
